==> fhcore-libs-0.2.5.4.tar.gz: fhcore-libs-0.2.5.4/fhcore/apps/facebook/models.py <==
# -*- coding: utf-8 -*-
""" Frankhood >  fhcore.apps.facebook.models
    @author: Frankhood Business Solutions
    @author: Gaetano D'Onghia
"""
from __future__ import absolute_import, print_function, unicode_literals
from django.utils.encoding import python_2_unicode_compatible

import logging

from django.conf import settings
from django.contrib.auth import get_user_model
from django.db import models
from django.utils.translation import ugettext_lazy as _

from django_extensions.db.fields.json import JSONField

from fhcore.models.base import BaseModel
from fhcore.apps.facebook import settings as app_settings
from fhcore.apps.facebook.managers import PlayerManager

logger = logging.getLogger(__name__)

try:
    # Django <= 1.6 backwards compatibility
    from django.utils import simplejson as json
except ImportError:
    # Django >= 1.7
    import json

User = get_user_model()


class AccountBaseMixin(models.Model):
    username = models.CharField(_("Username"), max_length=255, blank=True, null=True)
    first_name = models.CharField(_("First Name"), max_length=255, blank=True, null=True)
    last_name = models.CharField(_("Last Name"), max_length=255, blank=True, null=True)
    email = models.EmailField(_('Email facebook'), blank=True)
    personal_data = models.BooleanField(_('Acconsente al trattamento dei dati a fini informativi e promozionali'), default=False)

    class Meta(BaseModel.Meta):
        abstract = True

    @property
    def get_first_name(self):
        return self.first_name    

    @property
    def get_last_name(self):
        return self.last_name

    @property
    def get_full_name(self):
        return "{0} {1}".format(self.get_first_name ,self.get_last_name)

    @property
    def get_user_name(self):
        return self.username or self.get_full_name
   
class AccountAdvancedMixin(AccountBaseMixin):
    gender = models.CharField(_('Sesso'), max_length=10, blank=True,null=True)
    phone = models.CharField(_("Phone"), max_length=18, blank=True, null=True)
    birthdate = models.DateField(_('Data di nascita'), blank=True, null=True)
    avatar = models.ImageField(_("Avatar"), max_length=255, 
                 upload_to='uploads/game/players/avatars',
                 blank=True, null=True)

    class Meta(BaseModel.Meta):
        abstract = True

  
@python_2_unicode_compatible
class Player(AccountAdvancedMixin, BaseModel):
    
    objects = PlayerManager()
    
    type = models.CharField(_("Tipologia Player"), choices=app_settings.PLAYER_CHOICES, max_length=155)
    id_attribute = models.CharField(_("Identificativo Player"), max_length=155,db_index=True)
    # lo user può non esserci per esempio se si tratta di un facebook user
    user = models.ForeignKey(User, verbose_name=_("User"), related_name= "%(class)ss", 
                             blank=True, null=True)
    
    extra_data = JSONField()

    class Meta(BaseModel.Meta):
        abstract = True
        app_label = "game"
        ordering = ['-created',] #ordinati x created : LIFO
        verbose_name= _('Player')
        verbose_name_plural= _('Players') 

    @property
    def get_avatar_url(self):
        return "https://graph.facebook.com/{0}/picture?width={1}&height={2}".format(self.id_attribute,91,91)
    
    @property
    def facebook_id(self):
        if self.type == settings.FB_PLAYER_TYPE:
            return self.id_attribute
        return None
    
    @property
    def get_first_name(self):
        datadict = self.extra_data#json.loads(self.extra_data)
        if self.user:
            first_name = self.first_name or datadict.get('first_name',self.user.first_name)
        else:
            first_name = self.first_name or datadict.get('first_name','')
        return first_name    

    @property
    def get_last_name(self):
        datadict = self.extra_data#json.loads(self.extra_data)
        if self.user:
            last_name = self.last_name or datadict.get('last_name',self.user.last_name)
        else:
            last_name = self.last_name or datadict.get('last_name','')
        return last_name

    @property
    def get_full_name(self):
        return "{0} {1}".format(self.get_first_name ,self.get_last_name)

    @property
    def get_email(self):
        if self.email:
            return self.email
        elif self.user and self.user.email:
            return self.user.email
        return None

    @property
    def player_data(self):
        if self.username:
            return self.username
        else:
            if self.user:
                return self.user.get_full_name() or self.user.username
        return self.get_email #self.email or ''
   
    def __str__(self):
        try:
            return self.get_full_name
        except:
            return "{0}".format(self.player_data,)

==> fhcore-libs-0.2.6.2.tar.gz: fhcore-libs-0.2.6.2/fhcore/apps/facebook/models.py <==
# -*- coding: utf-8 -*-
""" Frankhood >  fhcore.apps.facebook.models
    @author: Frankhood Business Solutions
    @author: Gaetano D'Onghia
"""
from __future__ import absolute_import, print_function, unicode_literals
from django.utils.encoding import python_2_unicode_compatible

import logging

from django.conf import settings
from django.contrib.auth import get_user_model
from django.db import models
from django.utils.translation import ugettext_lazy as _

from django_extensions.db.fields.json import JSONField

from fhcore.models.base import BaseModel
from fhcore.apps.facebook import settings as app_settings
from fhcore.apps.facebook.managers import PlayerManager

logger = logging.getLogger(__name__)

try:
    # Django >= 1.7
    import json
except ImportError:
    # Django <= 1.6 backwards compatibility
    from django.utils import simplejson as json

User = get_user_model()


class AccountBaseMixin(models.Model):
    username = models.CharField(_("Username"), max_length=255, blank=True, null=True)
    first_name = models.CharField(_("Nome"), max_length=255, blank=True, null=True)
    last_name = models.CharField(_("Cognome"), max_length=255, blank=True, null=True)
    email = models.EmailField(_('Email'), blank=True)
    personal_data = models.BooleanField(_('Acconsente al trattamento dei dati a fini informativi e promozionali'), default=False)

    class Meta(BaseModel.Meta):
        abstract = True

    @property
    def get_first_name(self):
        return self.first_name    

    @property
    def get_last_name(self):
        return self.last_name

    @property
    def get_full_name(self):
        return "{0} {1}".format(self.get_first_name ,self.get_last_name)

    @property
    def get_user_name(self):
        return self.username or self.get_full_name
   
class AccountAdvancedMixin(AccountBaseMixin):
    gender = models.CharField(_('Sesso'), max_length=10, blank=True,null=True)
    phone = models.CharField(_("Telefono"), max_length=18, blank=True, null=True)
    birthdate = models.DateField(_('Data di nascita'), blank=True, null=True)
    avatar = models.ImageField(_("Avatar"), max_length=255, 
                 upload_to='uploads/game/players/avatars',
                 blank=True, null=True)

    class Meta(BaseModel.Meta):
        abstract = True

  
class Player(AccountAdvancedMixin, BaseModel):
    
    objects = PlayerManager()
    
    type = models.CharField(_("Tipologia Player"), choices=app_settings.PLAYER_CHOICES, max_length=155)
    id_attribute = models.CharField(_("Identificativo Player"), max_length=155,db_index=True)
    # lo user può non esserci per esempio se si tratta di un facebook user
    user = models.ForeignKey(User, verbose_name=_("User"), related_name= "%(class)ss", 
                             blank=True, null=True)
    
    extra_data = JSONField()

    class Meta(BaseModel.Meta):
        abstract = True
        app_label = "game"
        ordering = ['-created',] #ordinati x created : LIFO
        verbose_name= _('Player')
        verbose_name_plural= _('Players') 

    @property
    def get_avatar_url(self):
        return "https://graph.facebook.com/{0}/picture?width={1}&height={2}".format(self.id_attribute,91,91)
    
    @property
    def facebook_id(self):
        if self.type == app_settings.FB_PLAYER_TYPE:
            return self.id_attribute
        return None
    
    @property
    def get_first_name(self):
        datadict = self.extra_data#json.loads(self.extra_data)
        if self.user:
            first_name = self.first_name or datadict.get('first_name',self.user.first_name)
        else:
            first_name = self.first_name or datadict.get('first_name','')
        return first_name    

    @property
    def get_last_name(self):
        datadict = self.extra_data#json.loads(self.extra_data)
        if self.user:
            last_name = self.last_name or datadict.get('last_name',self.user.last_name)
        else:
            last_name = self.last_name or datadict.get('last_name','')
        return last_name

    @property
    def get_full_name(self):
        return "{0} {1}".format(self.get_first_name ,self.get_last_name)

    @property
    def get_email(self):
        if self.email:
            return self.email
        elif self.user and self.user.email:
            return self.user.email
        return None

    @property
    def player_data(self):
        if self.username:
            return self.username
        else:
            if self.user:
                return self.user.get_full_name() or self.user.username
        return self.get_email #self.email or ''
   
    def __unicode__(self):
        try:
            return self.get_full_name
        except:
            return "{0}".format(self.player_data,)
